@@ -25,6 +25,8 @@ from . import non_mandatory_tour_frequency
 from . import parking_location_choice
 from . import stop_frequency
 from . import tour_mode_choice
+from . import tour_od_choice
+from . import tour_scheduling_probabilistic
 from . import trip_destination
 from . import trip_mode_choice
 from . import trip_purpose
