@@ -94,7 +94,11 @@ def initialize_tours(network_los, households, persons, trace_hh_id):
         model_settings=model_settings.get('annotate_tours'),
         trace_label=tracing.extend_trace_label(trace_label, 'annotate_tours'))
 
-    tours = patch_tour_ids(tours)
+    skip_patch_tour_ids = model_settings.get('skip_patch_tour_ids', False)
+    if skip_patch_tour_ids:
+        pass
+    else:
+        tours = patch_tour_ids(tours)
     assert tours.index.name == 'tour_id'
 
     # replace table function with dataframe
