@@ -92,17 +92,18 @@ def validate_injectable(name):
 
 def handle_standard_args(args, multiprocess=True):
 
-    def inject_arg(name, value):
+    def inject_arg(name, value, cache=False):
         assert name in INJECTABLES
-        inject.add_injectable(name, value)
+        inject.add_injectable(name, value, cache=cache)
 
     if args.working_dir:
         # activitysim will look in the current working directory for
         # 'configs', 'data', and 'output' folders by default
         os.chdir(args.working_dir)
 
+    # settings_file_name should be cached or else it gets squashed by config.py
     if args.settings_file:
-        inject_arg('settings_file_name', args.settings_file)
+        inject_arg('settings_file_name', args.settings_file, cache=True)
 
     if args.config:
         inject_arg('configs_dir', args.config)
