@@ -13,6 +13,7 @@ from activitysim.core import util
 from activitysim.core import config
 from activitysim.core import pipeline
 from activitysim.core import chunk
+from activitysim.core import inject
 
 logger = logging.getLogger(__name__)
 
@@ -183,9 +184,11 @@ def assign_variables(assignment_expressions, df, locals_dict, df_alias=None,
     lowercase variables starting with underscore are temp variables (e.g. _local_var)
     and not returned except in trace_results
 
-    uppercase variables starting with underscore are temp scalar variables (e.g. _LOCAL_SCALAR)
+    uppercase variables starting with underscore are temp singular variables (e.g. _LOCAL_SCALAR)
     and not returned except in trace_assigned_locals
-    This is useful for defining general purpose local constants in expression file
+    This is useful for defining general purpose local variables that don't vary across
+    choosers or alternatives and therefore don't need to be stored as series/columns
+    in the main choosers dataframe from which utilities are computed.
 
     Users should take care that expressions (other than temp scalar variables) should result in
     a Pandas Series (scalars will be automatically promoted to series.)
@@ -212,6 +215,15 @@ def assign_variables(assignment_expressions, df, locals_dict, df_alias=None,
 
     np_logger = NumpyLogger(logger)
 
+    def is_throwaway(target):
+        return target == '_'
+
+    def is_temp_singular(target):
+        return target.startswith('_') and target.isupper()
+
+    def is_temp_series_val(target):
+        return target.startswith('_')
+
     def to_series(x):
         if x is None or np.isscalar(x):
             return pd.Series([x] * len(df.index), index=df.index)
@@ -245,6 +257,7 @@ def assign_variables(assignment_expressions, df, locals_dict, df_alias=None,
 
     # need to be able to identify which variables causes an error, which keeps
     # this from being expressed more parsimoniously
+
     for e in zip(assignment_expressions.target, assignment_expressions.expression):
         target, expression = e
 
@@ -258,7 +271,7 @@ def assign_variables(assignment_expressions, df, locals_dict, df_alias=None,
         if trace_label:
             logger.debug(f"{trace_label}.assign_variables {target} = {expression}")
 
-        if is_temp_scalar(target) or is_throwaway(target):
+        if is_temp_singular(target) or is_throwaway(target):
             try:
                 x = eval(expression, globals(), _locals_dict)
             except Exception as err:
@@ -297,6 +310,9 @@ def assign_variables(assignment_expressions, df, locals_dict, df_alias=None,
             logger.exception(f"assign_variables - {type(err).__name__} ({str(err)}) evaluating: {str(expression)}")
             raise err
 
+        if not is_temp_series_val(target):
+            variables[target] = expr_values
+
         if trace_results is not None:
             trace_results[uniquify_key(trace_results, target)] = expr_values[trace_rows]
 
