@@ -697,15 +697,18 @@ class MazSkimDict(SkimDict):
                               backstop_fractions * backstop_values + (1 - backstop_fractions) * values)
 
         elif is_nan.any():
-
             # print(f"{is_nan.sum()} nans out of {len(is_nan)} for key '{self.key}")
 
             if key in self.base_keys:
+
                 # replace nan values using simple backstop without blending
                 backstop_values = super().lookup(orig, dest, key)
                 values = np.where(is_nan, backstop_values, values)
             else:
                 # FIXME - if no backstop skim, then return 0 (which conventionally means "not available")
+                logger.warning(
+                    "No backstop skims found for {0}, so setting Nulls to 0. Make sure "
+                    "mode availability flags are set to > 0")
                 values = np.where(is_nan, 0, values)
 
         # want to return same type as backstop skim
